from django.db import models
from django.utils.translation import gettext_lazy as _


class Base(models.Model):
    created_at = models.DateTimeField(
        _("Created at"),
        help_text=_("Date and time on which the object was created"),
        auto_now_add=True,
    )
    updated_at = models.DateTimeField(
        _("Updated at"),
        help_text=_("Date and time on which the object was updated"),
        auto_now=True,
    )
    status = models.BooleanField(
        _("Status"),
        help_text=_("Status of the object"),
        default=True,
    )

    class Meta:
        abstract = True


class Service(Base):
    """Model definition for Service."""

    name = models.CharField(
        _("Name"), help_text=_("Name of the service"), max_length=255
    )
    slug = models.SlugField(_("Slug"), help_text=_("Slug of the service"), unique=True)
    description = models.TextField(
        _("Description"), help_text=_("Description of the service")
    )
    image = models.ImageField(
        _("Image"), help_text=_("Image of the service"), upload_to="services"
    )

    class Meta:
        """Meta definition for Service."""

        verbose_name = _("Service")
        verbose_name_plural = _("Services")

    def __str__(self):
        """Unicode representation of Service."""
        return self.name


class InstalledApp(Base):
    """Model definition for App."""

    name = models.CharField(
        _("Installed App"),
        help_text=_("InstalledApp"),
        max_length=255,
    )

    class Meta:
        """Meta definition for App."""

        verbose_name = _("InstalledApp")
        verbose_name_plural = _("Installed Apps")

    def __str__(self):
        """Unicode representation of Installed App."""
        return self.name


class AppPermission(Base):
    """Model definition for App Permission."""

    installed_app = models.ForeignKey(
        InstalledApp,
        on_delete=models.CASCADE,
        related_name="permissions",
    )
    name = models.CharField(
        max_length=255,
    )
    codename = models.CharField(
        max_length=100,
    )

    class Meta:
        """Meta definition for App Permission."""

        verbose_name = _("App Permission")
        verbose_name_plural = _("App Permissions")

    def __str__(self):
        """Unicode representation of App Permission."""
        return f"{self.installed_app.name}: {self.name} ({self.codename})"


class ServiceApps(Base):
    """Model definition for Service Apps."""

    service = models.ForeignKey(
        Service,
        on_delete=models.CASCADE,
        related_name="apps",
    )
    apps = models.ManyToManyField(
        InstalledApp,
        related_name="services",
    )

    class Meta:
        """Meta definition for Service Apps."""

        verbose_name = _("Service Apps")
        verbose_name_plural = _("Service Apps")

    def __str__(self):
        """Unicode representation of Service Apps."""
        return f"{self.service.name} Apps"



# management/commands/insert_installed_apps_and_permissions.py
from django.core.management.base import BaseCommand
from django.conf import settings
from django.contrib.auth.models import Permission
from django.apps import apps
from artd_service.models import (
    InstalledApp,
    AppPermission,
)  # Asegúrate de importar tus modelos correctamente


class Command(BaseCommand):
    help = "Insert installed apps and their permissions into the database"

    def handle(self, *args, **kwargs):
        # Obtener el listado de aplicaciones instaladas
        installed_apps = settings.INSTALLED_APPS

        for app in installed_apps:
            # Excluir las aplicaciones predeterminadas de Django
            if app.startswith("django."):
                continue

            # Crear o actualizar el registro en la base de datos para la aplicación
            installed_app, created = InstalledApp.objects.get_or_create(name=app)

            try:
                # Obtener el AppConfig para la aplicación
                app_config = apps.get_app_config(app.split(".")[-1])
            except LookupError:
                self.stdout.write(
                    self.style.WARNING(
                        f'No installed app with label {app.split(".")[-1]}'
                    )
                )
                continue

            # Obtener todos los modelos de la aplicación
            for model in app_config.get_models():
                # Obtener todos los permisos para el modelo
                permissions = Permission.objects.filter(
                    content_type__app_label=app_config.label,
                    content_type__model=model._meta.model_name,
                )
                for perm in permissions:
                    # Crear o actualizar el registro en la base de datos para el permiso
                    AppPermission.objects.get_or_create(
                        installed_app=installed_app,
                        name=perm.name,
                        codename=perm.codename,
                    )

        self.stdout.write(
            self.style.SUCCESS(
                "Successfully inserted installed apps and their permissions into the database"
            )
        )



from django.utils.translation import gettext_lazy as _

SERVICES = (
    (
        1,
        "parking",
        _("Parking"),
        "https://yopidoyopago.s3.us-east-2.amazonaws.com/images/services/parking-area.png",
    ),
    (
        2,
        "bar",
        _("Bar"),
        "https://yopidoyopago.s3.us-east-2.amazonaws.com/images/services/cocktail.png",
    ),
    (
        3,
        "restaurant",
        _("Restaurant"),
        "https://yopidoyopago.s3.us-east-2.amazonaws.com/images/services/restaurant.png",
    ),
    (
        4,
        "club",
        _("Club"),
        "https://yopidoyopago.s3.us-east-2.amazonaws.com/images/services/club.png",
    ),
)



# Generated by Django 5.0.7 on 2024-07-30 20:05

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_service", "0005_apppermission_created_at_apppermission_status_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="ServiceApps",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        help_text="Date and time on which the object was created",
                        verbose_name="Created at",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True,
                        help_text="Date and time on which the object was updated",
                        verbose_name="Updated at",
                    ),
                ),
                (
                    "status",
                    models.BooleanField(
                        default=True,
                        help_text="Status of the object",
                        verbose_name="Status",
                    ),
                ),
                (
                    "apps",
                    models.ManyToManyField(
                        related_name="services", to="artd_service.installedapp"
                    ),
                ),
                (
                    "service",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="apps",
                        to="artd_service.service",
                    ),
                ),
            ],
            options={
                "verbose_name": "Service Apps",
                "verbose_name_plural": "Service Appss",
            },
        ),
    ]



# management/commands/insert_installed_apps.py
from django.core.management.base import BaseCommand
from django.conf import settings
from artd_service.models import InstalledApp


class Command(BaseCommand):
    help = "Insert installed apps into the InstalledApp model"

    def handle(self, *args, **kwargs):
        # Obtener el listado de aplicaciones instaladas
        installed_apps = settings.INSTALLED_APPS

        # Insertar cada aplicación en el modelo InstalledApp
        for app in installed_apps:
            # Excluir las aplicaciones predeterminadas de Django
            if app.startswith("django."):
                continue

            # Crear o actualizar el registro en la base de datos
            InstalledApp.objects.get_or_create(name=app)

        self.stdout.write(
            self.style.SUCCESS("Successfully inserted installed apps into the model")
        )
